# OptiData Core Package

Este proyecto corresponde al package para OptiData. Este package contiene las siguientes dependencias:

- APScheduler>=3.10.4
- Flask>=3.0.2
- Flask-Bcrypt==1.0.1
- flask-restx>=1.3.0
- joblib>=1.3.2
- kafka-python>=2.0.2
- numpy>=1.26.4
- openpyxl>=3.1.2
- oracledb==2.1.0
- paramiko~=3.4.0
- pandas>=2.2.1
- pymongo>=4.3.3
- pysftp==0.2.9
- sqlalchemy==2.0.28
- vaex>=4.17.0